extern Ft_mathyyparse(void);
extern char *Ft_Read(void);
extern char *Ft_expandedline(char *prompt, int type, int *eof);
extern char *Ft_nextline(char *, int *);
extern char *Ft_nextline(char *prompt, int *eof);
extern char *Ft_read_loop(char **argv, char *fprom);
extern char *Ft_var_generator(char *text, int state);
extern char *rl_readline(char *);
extern char *username_completion_function();
extern double **Ft_dmatrix(int nrl, int nrh, int ncl, int nch);
extern double *Ft_dvector(int nl, int nh);
extern double asin(double), atan(double);
extern double cbrt(double), atanh(double), asinh(double), acosh(double);
extern double cosh(double), sinh(double), tanh(double);
extern double drand48(void);
extern double exp(double), sqrt(double);
extern double gamma(double);
extern double lgamma(double);
extern double log(double), log10(double), acos(double);
extern int *Ft_ivector(int nl, int nh);
extern int Ft_almost (char *, char *);
extern int Ft_almost (register char *str1, register char *str2);
extern int Ft_almost(char *, char *);
extern int Ft_almost(register char *str1, register char *str2);
extern int Ft_autosymremove (int level);
extern int Ft_autosymremove(int);
#ifdef VOID_SIGHANDLER
#define SIGHANDLER void
#else
#define SIGHANDLER int
#endif
extern SIGHANDLER Ft_catcher(int);
extern int Ft_cleansym (void);
extern int Ft_clearpop_cwd (void);
extern int Ft_clearpop_if (void);
extern int Ft_clearpush_cwd (void);
extern int Ft_command (int , char **, char *);
extern int Ft_dumplot (double **dblv, int ndata);
extern int Ft_exit (int val);
extern int Ft_fits (int argc, char **argv, int ndata);
extern int Ft_funcprocnotdef (void);
extern int Ft_ifexp (char *cline);
extern int Ft_iflevel (void);
extern int Ft_ifrun (int c, char *v);
extern int Ft_initdl (void);
extern int Ft_initmac (void);
extern int Ft_initreadline (void);
extern int Ft_initsetup (void);
extern int Ft_filelevel (void);
extern int Ft_iolevel (void);
extern int Ft_killplot (void);
extern int Ft_killplot(void);
extern int Ft_lfit(double **coef, double *y, double *sig, int ndata, double *a, int ma, int *lista, int mfit, double **covar, double *chisq);
extern int Ft_lock (int i, char *name, char *fname);
extern int Ft_macremove (char *name, int type);
extern int Ft_mathyyparse (void);
extern int Ft_more_input (int level, char *iprompt);
extern int Ft_more_input(int, char *);
extern int Ft_mrqmin(double **coef, double *f, double *y, double *sig, int ndata, double *a, int ma, int *lista, int mfit, double **covar, double **alpha, double *chisq, double *alamda);
extern int Ft_pop_cwd (void);
extern int Ft_popif (void);
extern int Ft_popio (void);
extern int Ft_printversion(void);
extern int Ft_processline (char *lp);
extern int Ft_push_cwd (void);
extern int Ft_pushif (int val);
extern int Ft_pushio (char *string, int type, char *name);
extern int Ft_run (void);
extern int Ft_run_fft (int argc, char **argv, int dir, int ndata);
extern int Ft_run_smooth (int argc, char **argv, int ndata);
extern int Ft_save_macros (int type, char *name, char *mode);
extern int Ft_setparam (char *name, int n);
extern int Ft_showfit (void);
extern int Ft_showmac (int argc, char **argv, int type);
extern int Ft_showmem (void);
extern int Ft_showsetup (void);
extern int Ft_showtable (void);
extern int Ft_spline (double *x, double *y, double yp1, double ypn, int n);
extern int Ft_svdfit(double **coef, double *y, double *sig, int ndata, double *a, int ma, double **v, double *w, double *chisq);
extern int Ft_svdvar (double **v, int ma, double *w, double **cvm);
extern int Ft_switchif (int val);
extern int Ft_symremove (char *name, int verb);
extern int Ft_varcpy (char *, char *);
extern int Ft_varcpy(char *, char *);
extern int Ft_vgetargp (char *b, char **p, int type, char **add);
extern int Ft_vgetargp(char *b, char **p, int type, char **add);
extern int append_history(int, char *);
extern int history_expand(char *, char **);
extern int write_history(char *);
extern void Ft_cleanframe (void);
extern void Ft_fit (double *x, double *y, int ndata, double *sig, int mwt, double *a, double *b, double *siga, double *sigb, double *chi2, double *q);
extern void Ft_free_dmatrix(double **m, int nrl, int nrh, int ncl, int nch);
extern void Ft_free_dvector (double *v, int nl, int nh);
extern void Ft_free_dvector(double *v, int nl, int nh);
extern void Ft_free_ivector(int *v, int nl, int nh);
extern void Ft_initcode (void);
extern void Ft_initmacros (void);
extern void Ft_initmathyylex (char *str);
extern void Ft_initparser (void);
extern void Ft_initstacks (void);
extern void Ft_matherror (char *s1, char *s2, int lino);
extern void Ft_matherror(char *, char *, int);
extern void Ft_mathuser(void);
extern void Ft_medfit (double *x, double *y, int ndata, double *a, double *b, double *abdev);
extern void Ft_pearsn (double *x, double *y, int n, double *r, double *prob, double *z);
extern void Ft_resetindex(void);
extern void Ft_resetprog(void);
extern void add_history(char *);
int Ft_printversion (void);
void Ft_reaperon(void);
void Ft_reaperoff(void);
